rnalysis.feature\_name\_to\_wbgene.name\_to\_wbgene\_folder
===========================================================

.. currentmodule:: rnalysis.feature_name_to_wbgene

.. autofunction:: name_to_wbgene_folder